@@ -1,5 +1,5 @@
 /* dom.h
- * $Id: dom.h 792 2009-09-24 08:36:11Z pajas $
+ * $Id: dom.h 597 2006-09-21 22:25:25Z pajas $
  * Author: Christian Glahn (2001)
  * 
  * This header file provides some definitions for wrapper functions.
@@ -20,30 +20,8 @@
 #ifndef __LIBXML_DOM_H__
 #define __LIBXML_DOM_H__
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#include "EXTERN.h"
-#include "perl.h"
-#include "XSUB.h"
-#include "ppport.h"
-
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
-#include <libxml/encoding.h>
-#include <libxml/xmlerror.h>
-#include <libxml/xmlmemory.h>
-#include <libxml/parser.h>
-#include <libxml/parserInternals.h>
-#include <libxml/xmlIO.h>
-#include <libxml/xpathInternals.h>
-#include <libxml/globals.h>
-#include <stdio.h>
-
-#ifdef __cplusplus
-}
-#endif
 
 /**
  * part 0:
@@ -51,8 +29,6 @@ extern "C" {
  * unsortet. 
  **/
 
-void
-domReconcileNs(xmlNodePtr tree);
 
 /**
  * NAME domParseChar
@@ -212,6 +188,9 @@ domGetNodeValue( xmlNodePtr self );
 void
 domSetNodeValue( xmlNodePtr self, xmlChar* value );
 
+void
+domSetParentNode( xmlNodePtr self, xmlNodePtr newParent );
+
 xmlNodePtr
 domReplaceNode( xmlNodePtr old, xmlNodePtr new );
 
@@ -225,7 +204,7 @@ domReplaceNode( xmlNodePtr old, xmlNodePtr new );
  * NAME domImportNode
  * TYPE function
  * SYNOPSIS
- * node = domImportNode( document, node, move, reconcileNS);
+ * node = domImportNode( document, node, move);#
  *
  * the function will import a node to the given document. it will work safe
  * with namespaces and subtrees. 
@@ -234,13 +213,11 @@ domReplaceNode( xmlNodePtr old, xmlNodePtr new );
  * original document. if move is set to 0, the node will be copied with the 
  * deep option. 
  *
- * if reconcileNS is 1, namespaces are reconciled.
- *
  * the function will return the imported node on success. otherwise NULL
  * is returned 
  */
 xmlNodePtr
-domImportNode( xmlDocPtr document, xmlNodePtr node, int move, int reconcileNS );
+domImportNode( xmlDocPtr document, xmlNodePtr node, int move );
 
 /**
  * part C:
@@ -272,10 +249,4 @@ domNodeNormalizeList( xmlNodePtr nodelist );
 int
 domRemoveNsRefs(xmlNodePtr tree, xmlNsPtr ns);
 
-void
-domAttrSerializeContent(xmlBufferPtr buffer, xmlAttrPtr attr);
-
-void
-domClearPSVI(xmlNodePtr tree);
-
 #endif
